==> jboss-4.0.4.GA-src.tar.gz: jboss-4.0.4.GA-src/testsuite/src/main/org/jboss/test/webservice/jbws349/ServiceFacadeEndpointImpl.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.webservice.jbws349;

import org.jboss.logging.Logger;

public class ServiceFacadeEndpointImpl implements ServiceFacadeEndpoint
{
   // provide logging
   private static final Logger log = Logger.getLogger(ServiceFacadeEndpointImpl.class);

   public Result processEvent(Event event) throws EventException
   {
      log.info("processEvent: " + event);
      
      Result res;
      if (event instanceof AssetCreate)
      {
         res = new AssetCreateResult("123");
      }
      else if (event instanceof AssetRead)
      {
         res = new AssetReadResult("123", "body");
      }
      else
      {
         throw new EventException("Invalid event");
      }
      
      return res;
   }
}

==> jboss-4.0.5.GA-src.tar.gz: jboss-4.0.5.GA-src/testsuite/src/main/org/jboss/test/webservice/jbws349/ServiceFacadeEndpointImpl.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.test.webservice.jbws349;

import org.jboss.logging.Logger;

public class ServiceFacadeEndpointImpl implements ServiceFacadeEndpoint
{
   // provide logging
   private static final Logger log = Logger.getLogger(ServiceFacadeEndpointImpl.class);

   public Result processEvent(Event event) throws EventException
   {
      log.info("processEvent: " + event);
      
      Result res;
      if (event instanceof AssetCreate)
      {
         res = new AssetCreateResult(event.getId());
      }
      else if (event instanceof AssetRead)
      {
         res = new AssetReadResult(event.getId(), "body");
      }
      else
      {
         throw new EventException("Invalid event");
      }
      
      return res;
   }
}
